==> humhub-1.3.18.tar.gz: humhub-1.3.18/protected/humhub/messages/pl/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => 'Potwierdź akcję',
  '<strong>Latest</strong> updates' => '<strong>Najnowsze</strong> aktualizacje',
  '<strong>Mail</strong> summary' => '<strong>Mail</strong> podsumowanie',
  'Account settings' => 'Ustawienia konta',
  'Add:' => 'Dodaj:',
  'Administration' => 'Administracja',
  'Allow' => 'Zezwól',
  'An error occurred while handling your last action. (Handler not found).' => 'Wystąpił błąd podczas wykonywania ostatniej czynności. (Handler not found).',
  'An unexpected error occurred while loading the search result.' => 'Wystąpił nieoczekiwany błąd podczas ładowania wyników wyszukiwania.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Wystąpił nieoczekiwany błąd. Jeśli problem będzie się powtarzał, skontaktuj się z administratorem strony.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Wystąpił nieoczekiwany błąd serwera. Jeśli problem będzie się powtarzał, skontaktuj się z administratorem strony.',
  'An unknown error occurred while uploading.' => 'Wystąpił nieznany błąd podczas ładowania.',
  'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Wystąpił nieznany błąd podczas ładowania.  Podpowiedź: sprawdź ustawienia upload_max_filesize i post_max_size php.',
  'Back' => 'Wstecz',
  'Back to dashboard' => 'Powrót do pulpitu',
  'Cancel' => 'Anuluj',
  'Choose language:' => 'Wybierz język:',
  'Close' => 'Zamknij',
  'Collapse' => 'Zwiń',
  'Confirm' => 'Potwierdź',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Źródło zawartości dodatku musi być instancją HActiveRecordContent lub HActiveRecordContentAddon!',
  'Copy to clipboard' => 'Kopiuj do schowka.',
  'Could not find content of addon!' => 'Nie znaleziono zawartości dodatku!',
  'Could not find requested page.' => 'Nie znaleziono strony.',
  'Default' => 'Domyślny',
  'Delete' => 'Usuń',
  'Deny' => 'Blokuj',
  'Do you really want to perform this action?' => 'Czy na pewno chcesz wykonać tę czynność?',
  'Edit' => 'Edytuj',
  'Error' => 'Błąd',
  'Error while running your last action (Invalid request method).' => 'Wystapił błąd podczasy wykonania ostatniej czynności (Nieprawidłowa metoda żądania).',
  'Error:' => 'Błąd:',
  'Expand' => 'Rozwiń',
  'Export' => 'Eksportuj',
  'Info:' => 'Info:',
  'Invalid request method!' => 'Błędna metoda żądania!',
  'It looks like you may have taken the wrong turn.' => 'Chyba zabłądziłeś.',
  'Language' => 'Język',
  'Loading...' => 'Ładowanie...',
  'Login' => 'Zaloguj',
  'Logo of {appName}' => 'Logo {appName}',
  'Logout' => 'Wyloguj',
  'Menu' => 'Menu',
  'Module is not enabled on this content container!' => 'Moduł w tym kontenerze nie jest uruchomiony!',
  'My profile' => 'Mój profil',
  'My profile image' => 'Mój obrazek profilowy',
  'New profile image' => 'Nowe zdjęcie profilowe',
  'Next' => 'Dalej',
  'No error information given.' => 'Nie podano informacji o błędzie.',
  'Oooops...' => 'Upsss...',
  'Open' => 'Otwórz',
  'Please type at least 3 characters' => 'Wpisz przynajmniej 3 znaki',
  'Please type at least {count} characters' => 'Wpisz przynajmniej {count} litery',
  'Powered by {name}' => 'Od {name}',
  'Profile dropdown' => 'Rozwiń Profil',
  'Profile image of {displayName}' => 'Obraz profilowy {displayName}',
  'Profile picture of {displayName}' => 'Zdjęcie profilowe {displayName}',
  'Save' => 'Zapisz',
  'Saved' => 'Zapisano',
  'Search' => 'Szukaj',
  'Select Me' => 'Wybierz mnie',
  'Show less' => 'Pokaż mniej',
  'Show more' => 'Pokaż więcej',
  'Some files could not be uploaded:' => 'Niektóre pliki nie mogą zostać przesłane:',
  'Text could not be copied to clipboard' => 'Tekst nie mógł zostać skopiowany do schowka',
  'Text has been copied to clipboard' => 'Tekst został skopiowany do schowka',
  'The date has to be in the past.' => 'Wpisana data musi być wcześniejsza.',
  'The file has been deleted.' => 'Plik został usunięty.',
  'The requested resource could not be found.' => 'Żądany zasób nie został znaleziony.',
  'The space has been archived.' => 'Strefa ma zostać zarchiwizowana.',
  'The space has been unarchived.' => 'Strefa ma zostać rozpakowana.',
  'Time Zone' => 'Strefa czasowa',
  'Toggle comment menu' => 'Przełącz menu komentarzy',
  'Toggle panel menu' => 'Przełącz menu panela',
  'Toggle post menu' => 'Przełącz menu wpisów',
  'Toggle stream entry menu' => 'Przełącz menu wpisu źródła',
  'Unsubscribe' => 'Anuluj subskrybcję',
  'Upload' => 'Prześlij',
  'Upload file' => 'Prześlij plik',
  'You are not allowed to run this action.' => 'Nie posiadasz uprawnień do wykonania tej czynności.',
);

==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/messages/pl/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => '<strong>Potwierdź</strong> Akcje',
  '<strong>Latest</strong> updates' => '<strong>Najnowsze</strong> aktualizacje',
  '<strong>Mail</strong> summary' => '<strong>Mail</strong> podsumowanie',
  'Account settings' => 'Ustawienia konta',
  'Add:' => 'Dodaj:',
  'Administration' => 'Administracja',
  'Allow' => 'Zezwól',
  'An error occurred while handling your last action. (Handler not found).' => 'Wystąpił błąd podczas wykonywania ostatniej czynności. (Handler not found).',
  'An unexpected error occurred while loading the search result.' => 'Wystąpił nieoczekiwany błąd podczas ładowania wyników wyszukiwania.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Wystąpił nieoczekiwany błąd. Jeśli problem będzie się powtarzał, skontaktuj się z administratorem strony.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Wystąpił nieoczekiwany błąd serwera. Jeśli problem będzie się powtarzał, skontaktuj się z administratorem strony.',
  'An unknown error occurred while uploading.' => 'Wystąpił nieznany błąd podczas ładowania.',
  'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Wystąpił nieznany błąd podczas ładowania.  Podpowiedź: sprawdź ustawienia upload_max_filesize i post_max_size php.',
  'Back' => 'Wstecz',
  'Back to dashboard' => 'Powrót do pulpitu',
  'Cancel' => 'Anuluj',
  'Choose language:' => 'Wybierz język:',
  'Close' => 'Zamknij',
  'Collapse' => 'Zwiń',
  'Confirm' => 'Potwierdź',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Źródło zawartości dodatku musi być instancją HActiveRecordContent lub HActiveRecordContentAddon!',
  'Copy to clipboard' => 'Kopiuj do schowka',
  'Could not find content of addon!' => 'Nie znaleziono zawartości dodatku!',
  'Could not find requested page.' => 'Nie znaleziono strony.',
  'Default' => 'Domyślny',
  'Delete' => 'Usuń',
  'Deny' => 'Odmów',
  'Do you really want to perform this action?' => 'Czy na pewno chcesz wykonać tę czynność?',
  'Edit' => 'Edytuj',
  'Error' => 'Błąd',
  'Error while running your last action (Invalid request method).' => 'Wystapił błąd podczasy wykonania ostatniej czynności (Nieprawidłowa metoda żądania).',
  'Error:' => 'Błąd:',
  'Expand' => 'Rozwiń',
  'Export' => 'Eksportuj',
  'Info:' => 'Info:',
  'Invalid request method!' => 'Błędna metoda żądania!',
  'It looks like you may have taken the wrong turn.' => 'Chyba zabłądziłeś.',
  'Language' => 'Język',
  'Loading...' => 'Ładowanie...',
  'Login' => 'Zaloguj',
  'Logo of {appName}' => 'Logo {appName}',
  'Logout' => 'Wyloguj',
  'Menu' => 'Menu',
  'Module is not enabled on this content container!' => 'Moduł w tym kontenerze nie jest aktywny!',
  'My profile' => 'Mój profil',
  'My profile image' => 'Moje zdjęcie profilowy',
  'New profile image' => 'Nowe zdjęcie profilowe',
  'Next' => 'Dalej',
  'No error information given.' => 'Nie podano informacji o błędzie.',
  'Oooops...' => 'Upsss...',
  'Open' => 'Otwórz',
  'Please type at least 3 characters' => 'Wpisz przynajmniej 3 znaki',
  'Please type at least {count} characters' => 'Wpisz przynajmniej {count} znaki',
  'Powered by {name}' => 'Od {name}',
  'Profile dropdown' => 'Rozwiń Profil',
  'Profile image of {displayName}' => 'Obraz profilowy {displayName}',
  'Profile picture of {displayName}' => 'Zdjęcie profilowe {displayName}',
  'Save' => 'Zapisz',
  'Saved' => 'Zapisano',
  'Search' => 'Szukaj',
  'Select Me' => 'Wybierz mnie',
  'Show less' => 'Pokaż mniej',
  'Show more' => 'Pokaż więcej',
  'Some files could not be uploaded:' => 'Niektóre pliki nie mogą zostać przesłane:',
  'Text could not be copied to clipboard' => 'Tekst nie mógł zostać skopiowany do schowka',
  'Text has been copied to clipboard' => 'Tekst został skopiowany do schowka',
  'The date has to be in the past.' => 'Wpisana data musi być wcześniejsza.',
  'The file has been deleted.' => 'Plik został usunięty.',
  'The requested resource could not be found.' => 'Żądany zasób nie został znaleziony.',
  'The space has been archived.' => 'Strefa ma zostać zarchiwizowana.',
  'The space has been unarchived.' => 'Strefa ma zostać rozpakowana.',
  'Time Zone' => 'Strefa czasowa',
  'Toggle comment menu' => 'Przełącz menu komentarzy',
  'Toggle panel menu' => 'Przełącz menu panela',
  'Toggle post menu' => 'Przełącz menu wpisów',
  'Toggle stream entry menu' => 'Przełącz menu wpisu źródła',
  'Unsubscribe' => 'Anuluj subskrybcję',
  'Upload' => 'Prześlij',
  'Upload file' => 'Prześlij plik',
  'You are not allowed to run this action.' => 'Nie posiadasz uprawnień do wykonania tej czynności.',
);
